jaclearn.datasets.image\_classification
=======================================

.. automodule:: jaclearn.datasets.image_classification

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Submodules
.. autosummary::
   :toctree:
   :template: base.rst
   :recursive:

   cifar
   mnist
   svhn









